@@ -632,8 +632,16 @@ def list_materializations(config: CLIContext, search: Optional[str] = None) -> N
 @pass_config
 @click.option("--metric-name", required=True, type=str, help="Metric that is associated with the dimension")
 @click.option("--dimension-name", required=True, type=str, help="Dimension to query")
+@click.option("--page-number", required=False, type=int, hidden=True)
+@click.option("--page-size", required=False, type=int, hidden=True)
 @exception_handler
-def get_dimension_values(config: CLIContext, dimension_name: str, metric_name: str) -> None:
+def get_dimension_values(
+    config: CLIContext,
+    dimension_name: str,
+    metric_name: str,
+    page_number: Optional[int] = None,
+    page_size: Optional[int] = None,
+) -> None:
     """List all dimension values that are queryable through materialized tables."""
 
     spinner = Halo(
@@ -644,7 +652,13 @@ def get_dimension_values(config: CLIContext, dimension_name: str, metric_name: s
     model_key = config.resolve_query_model_key()
     try:
         dim_vals = sorted(
-            config.mql.get_dimension_values(metric_name, dimension_name, model_key.id if model_key else None)
+            config.mql.get_dimension_values(
+                metric_name,
+                dimension_name,
+                model_key.id if model_key else None,
+                page_number=page_number,
+                page_size=page_size,
+            )
         )
     except Exception as e:
         spinner.fail()
@@ -811,14 +825,21 @@ def validate_configs(config: CLIContext, config_dir: str) -> None:
 @cli.command()
 @config_validation_options
 @click.option("--pin", type=bool, required=False, help="Whether to pin the model or not")
+@click.option("--force-primary", is_flag=True, default=False, help="Make this model current")
 @pass_config
 @click.pass_context
 @exception_handler
-def commit_configs(ctx: click.core.Context, config: CLIContext, config_dir: str, pin: bool = None) -> None:
+def commit_configs(
+    ctx: click.core.Context,
+    config: CLIContext,
+    config_dir: str,
+    pin: Optional[bool] = None,
+    force_primary: Optional[bool] = None,
+) -> None:
     """Commit yaml configs found in specified config directory"""
     spinner = Halo(text="Parsing and uploading configs…", spinner="dots")
     spinner.start()
-    model = config.mql.commit_configs(config_dir)
+    model = config.mql.commit_configs(config_dir, force_primary)
     spinner.succeed(
         f"🦄 Successfully committed configs id {model.id} on branch {model.branch} with commit {model.commit}"
     )
