@@ -113,10 +113,12 @@ class BackendInterface(BaseInterface):  # noqa: D
         super(BackendInterface, self).__init__(auth_header, rest_api_url, verify)
 
     def _get_and_upload_configs(
-        self, mode: str, config_dir: str, repo: str, branch: str, commit: str
+        self, mode: str, config_dir: str, repo: str, branch: str, commit: str, is_current: Optional[bool] = None
     ) -> requests.Response:  # noqa: D
         try:
-            return upload_configs(mode, self.auth_header, repo, branch, commit, config_dir, self.rest_api_url)
+            return upload_configs(
+                mode, self.auth_header, repo, branch, commit, config_dir, is_current, self.rest_api_url
+            )
         except Exception as e:
             error_content = str(e).split(ERROR_RESPONSE_PREFIX)
             error_msg = str(e)
@@ -132,10 +134,10 @@ class BackendInterface(BaseInterface):  # noqa: D
 
         return repo, branch, commit
 
-    def commit_configs(self, config_dir: str) -> ModelKey:
+    def commit_configs(self, config_dir: str, is_current: Optional[bool] = None) -> ModelKey:
         """Finds and validates yaml configs in the provided directory"""
         repo, branch, commit = resolve_local_commit_info(config_dir)
-        r = self._get_and_upload_configs("commit", config_dir, repo, branch, commit)
+        r = self._get_and_upload_configs("commit", config_dir, repo, branch, commit, is_current)
 
         return ModelKey.from_snake_dict(r.json()["model"])
 
@@ -549,8 +551,10 @@ class MQLInterface(BaseInterface):  # noqa: D
         self,
         metric_name: str,
         dimension_name: str,
-        allow_dynamic_cache: bool = False,
+        allow_dynamic_cache: bool = True,
         model_key: Optional[ModelKey] = None,
+        page_number: Optional[int] = None,
+        page_size: Optional[int] = None,
     ) -> List[str]:
         """Retrieve all dimension values of a given [metric,dimension].
 
@@ -558,9 +562,9 @@ class MQLInterface(BaseInterface):  # noqa: D
         """
         query = gql(
             """
-            query DimensionValueQuery($dimensionName: String!, $metricName: String!, $allowDynamicCache: Boolean, $modelKey: ModelKeyInput) {
+            query DimensionValueQuery($dimensionName: String!, $metricName: String!, $allowDynamicCache: Boolean, $modelKey: ModelKeyInput, $pageNumber: Int, $pageSize: Int) {
                 metricByName(modelKey: $modelKey, name: $metricName) {
-                    dimensionValues(dimensionName: $dimensionName, allowDynamicCache: $allowDynamicCache)
+                    dimensionValues(dimensionName: $dimensionName, allowDynamicCache: $allowDynamicCache, pageNumber: $pageNumber, pageSize: $pageSize)
                 }
             }
             """
@@ -577,6 +581,8 @@ class MQLInterface(BaseInterface):  # noqa: D
                 }
                 if model_key
                 else None,
+                "pageNumber": page_number,
+                "pageSize": page_size,
                 "dimensionName": dimension_name,
                 "metricName": metric_name,
                 "allowDynamicCache": allow_dynamic_cache,
